//
//  WriteReviewViewController.swift
//  iAppsReview
//
//  Created by Kevin McNeish on 3/8/15.
//  Copyright (c) 2015 Oak Leaf Enterprises, Inc. All rights reserved.
//

import UIKit

class WriteReviewViewController: UITableViewController,
	UIImagePickerControllerDelegate,
	UINavigationControllerDelegate, UITextViewDelegate, AppCategoryDelegate {

    var appCategoryID = 0
    
    lazy var review = Review()
    
    @IBOutlet weak var appCategoryCell: UITableViewCell!
    @IBOutlet weak var imgThumbnail: UIImageView!
    @IBOutlet weak var tvwReview: UITextView!
    @IBOutlet weak var btnShare: UIBarButtonItem!
    @IBOutlet weak var txtAppName: UITextField!
    @IBOutlet weak var btnPost: UIButton!
    @IBOutlet weak var starRating: mmStarRating!
    
    var image: UIImage?
    var imageURL: NSURL?
    
    @IBAction func postReview(sender: AnyObject) {
        
        // Create a new review entity and set its attributes
        // from the values of the UI controls
        let reviewEntity = self.review.createEntity()
        reviewEntity.categoryID = self.appCategoryID 
        reviewEntity.userID = 1	// hard code for now
        reviewEntity.isPosted = false	// hard code for now
        reviewEntity.rating = self.starRating.rating
        reviewEntity.appName = self.txtAppName.text
        reviewEntity.comments = self.tvwReview.text
        
        // Save the entity
        review.saveEntities()
        
        self.navigationController?.popViewControllerAnimated(true)
    }
    
    @IBAction func appNameChanged(sender: AnyObject) {
        
		self.enableDisableControls()
    }
    
    func textViewDidChange(textView: UITextView) {
        
        self.enableDisableControls()
    }
    
    func enableDisableControls() {
        self.btnShare.enabled = self.isReadyToShare()
        self.btnPost.enabled = self.isReadyToShare()
    }
    
    func isReadyToShare() -> Bool {
        // Check if either the text view or text field is empty
        if count(self.tvwReview.text) == 0 ||
            count(self.txtAppName.text) == 0 ||
        	self.appCategoryID == 0 {
            // One or both of them is empty
            return false
        }
        else {
            // Neither control is empty
            return true
        }
    }
    
    @IBAction func accessPhotoLibrary(sender: AnyObject) {
        
        // Create the image picker controller
        let imagePickerController = UIImagePickerController()
        
        // Set the image picker controller properties
        imagePickerController.sourceType = UIImagePickerControllerSourceType.PhotoLibrary
        
        // Store a reference to the view controller in the delegate property
        imagePickerController.delegate = self
        
        // Display the image picker controller
        self.presentViewController(imagePickerController, animated: true, completion: nil)
    }
    
    func imagePickerController(picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [NSObject : AnyObject]) {
        
        self.dismissViewControllerAnimated(true, completion: nil)
        self.image = info[UIImagePickerControllerOriginalImage] as? UIImage
        self.imgThumbnail.image = self.image
    }
    
    func imagePickerControllerDidCancel(picker: UIImagePickerController) {
        self.dismissViewControllerAnimated(true, completion: nil)
    }
    
    @IBAction func shareReview(sender: AnyObject) {
        
        let activityItems = [self.tvwReview.text]
        
        let avc = UIActivityViewController(activityItems: activityItems, applicationActivities: nil)
        
        self.presentViewController(avc, animated: true, completion: nil)
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        

        // Do any additional setup after loading the view.
    }
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if segue.identifier == "AppCategorySegue" {
            
            // Get the destination controller
            let controller = segue.destinationViewController as! AppCategoryViewController
            
            // Store the AppCategoryEntity ID on the destination controller
            controller.appCategoryID = self.appCategoryID
            
            // Store a reference to the view controller in the 
            // delegate property of the destination view controller
            controller.delegate = self
        }
    }
    
    func updateAppCategory(appCategoryEntity: AppCategoryEntity) {
        
        self.appCategoryID = appCategoryEntity.categoryID.integerValue
        self.appCategoryCell.detailTextLabel?.text = appCategoryEntity.name
        self.tableView.reloadData()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
